@@ -5,7 +5,8 @@ import json
 from firebase_admin import (
     auth as firebase_auth,
     credentials,
-    initialize_app as firebase_initialize_app
+    initialize_app as firebase_initialize_app,
+    get_app as get_firebase_app
 )
 
 PUBSUB_UID = 'pubsub@arcane.run'
@@ -36,3 +37,11 @@ def generate_token(firebase_api_key: str,
 def initialize_app(credentials_path: str) -> None:
     cred = credentials.Certificate(credentials_path)
     firebase_initialize_app(cred)
+
+
+def initialize_app_if_necessary(credentials_path: str) -> None:
+    try:
+        get_firebase_app()
+    except ValueError:
+        print(f"No app existed, initializing")
+        initialize_app(credentials_path)
